using System;
using System.Windows.Forms;
using System.Threading;

namespace KBBanki.AppLoaderDemo
{
	/// <summary>
	/// Class used to initialize and start the application.
	/// </summary>
	/// <internal>
	/// 	<author>
	///      <name>Sigurur G. Gunnarsson</name>
	///      <email>sigurdg@kbbanki.is</email>
	///   </author>
	///   <createdDate>13-07-2004</createdDate>
	/// </internal>
	public sealed class AppLoader
	{
		private static ApplicationContext m_oApplicationContext;

		private AppLoader()
		{
		}


		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main(string[] args)
		{	
			// Setup a new application context
			m_oApplicationContext = new ApplicationContext();
			// Register a handler to the Application.Idle event.  
			// This event will fire when the application is ready to move on (initialization done).
			Application.Idle += new EventHandler(Application_Idle);

			// Turn on XP themes support
			Application.EnableVisualStyles();
			Application.DoEvents();  // This is currently required to bypass a framework 1.1 bug.

			// Do other stuff at startup
			DoStartup(args);
		}


		private static void Application_Idle(object sender, EventArgs e)
		{
			if( m_oApplicationContext.MainForm == null)      
			{        
				// First detach the event so it won't run again
				Application.Idle -= new EventHandler( Application_Idle );  
				// Create an instance of the main form and show it
				m_oApplicationContext.MainForm = new Forms.GrunnForm();         
				m_oApplicationContext.MainForm.Show();            
			}  
		}

		private static void DoStartup(string[] args)
		{
			// Here you setup other stuff you need, like setting a principal policy, 
			// remoting config, global error handling etc.



			// And finally start the message pump loop.			
			Application.Run( m_oApplicationContext );
		}
	}
}
